@@ -1,33 +1,33 @@
 import os
-import webbrowser
 import json
 import re
 import sys
+import lxml.html
 from lxml import etree
 from lxml.builder import ElementMaker, E
-import lxml.html
+from io import BytesIO
 
 
 class BuilderHtmlGraph():
-    def __init__(self, parts, display_html, verbose):
+    def __init__(self, parts, verbose):
         self.parts = parts
-        self.display_html = display_html
         self.verbose = verbose
+        self.html_head = self._get_html_head()
+        self.script = self._get_part('script.js')
 
-    def save_html_and_open_html(self, dict_oval_trees, src, rules, out):
+    def save_html(self, dict_oval_trees, src, rules):
         self.save_html_report(dict_oval_trees, src)
-        self.print_output_message_and_open_web_browser(
-            src, self._format_rules_output(rules), out)
+        self.print_output_message(src, self._format_rules_output(rules))
 
     def save_html_report(self, dict_of_rules, src):
-        with open(src, "w+") as data_file:
+        with open(src, "wb+") as data_file:
             data_file.writelines(self._get_html(dict_of_rules))
 
     def _get_html(self, dict_of_rules):
         maker = ElementMaker(namespace=None,
                              nsmap={None: "http://www.w3.org/1999/xhtml"})
         html = maker.html(
-            self._get_html_head(),
+            self.html_head,
             self._get_html_body(dict_of_rules))
         result = etree.tostring(
             html,
@@ -39,7 +39,7 @@ class BuilderHtmlGraph():
             with_tail=False,
             method='html',
             pretty_print=True)
-        return result.decode('UTF-8')
+        return BytesIO(result)
 
     def _get_html_head(self):
         return E.head(
@@ -63,7 +63,7 @@ class BuilderHtmlGraph():
                         E.div({'id': 'content'}),
                         )
                   ),
-            E.script(self._get_part('script.js')),
+            E.script(self.script),
         )
 
     def _get_script_graph_data(self, dict_of_rules):
@@ -94,18 +94,9 @@ class BuilderHtmlGraph():
                 out += line
         return out
 
-    def print_output_message_and_open_web_browser(self, src, rule, out):
+    def print_output_message(self, src, rule):
         if self.verbose:
             print('Rule(s) "{}" done!'.format(rule), file=sys.stderr)
-        out.append(src)
-        self.open_web_browser(src)
-
-    def open_web_browser(self, src):
-        if self.display_html:
-            try:
-                webbrowser.get('firefox').open_new_tab(src)
-            except BaseException:
-                webbrowser.open_new_tab(src)
 
     def _format_rules_output(self, rules):
         out = ''
